// -*- c++ -*- 
/*****************************************************************************
 * class: Util
 *****************************************************************************/
#ifndef UTIL_H
#define UTIL_H

#include <gtk/gtk.h>

#include "TshObj.h"

class RowData;

class Util : public TshObj
{
public:
  Util();
  static char*  path(GtkCTreeNode*, char*, char*, int, int);
  static char*  editCmd(char*, GList*);
  static bool   treeList(RowData*, int, GList*);
  static int    exe(RowData*, int);
  static int    apply(RowData*, int, GList*);
  static bool   catTxt(RowData*, int);
  static bool   catImage(RowData*, int);
  static bool   canvasList(RowData*, int);
  static bool   clist(RowData*);
  static void   die(char*, char*);
  static FILE*  getfp(char*, char*, char*);
};
#endif
